Crate yellowstone_vixen_raydium_amm_v4_parser

Crate yellowstone_vixen_raydium_amm_v4_parser 

Modules

accounts
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
accounts_parser
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
errors
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
instructions
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
instructions_parser
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
programs
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
proto_def
proto_helpers
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
shared
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
types
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.

Constants

ID

Functions

deserialize_checked
Deserialize a Borsh-encoded account, checking that all significant bytes are read.